# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aioketraapi
from aioketraapi.api.hub_operations_api import HubOperationsApi  # noqa: E501
from aioketraapi.rest import ApiException


class TestHubOperationsApi(unittest.TestCase):
    """HubOperationsApi unit test stubs"""

    def setUp(self):
        self.api = aioketraapi.api.hub_operations_api.HubOperationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_hub_get(self):
        """Test case for hub_get

        Gets properties of the hub  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
