# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.button_change import ButtonChange  # noqa: E501
from aioketraapi.rest import ApiException

class TestButtonChange(unittest.TestCase):
    """ButtonChange unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ButtonChange
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.button_change.ButtonChange()  # noqa: E501
        if include_optional :
            return ButtonChange(
                notification_type = 'ButtonChange', 
                time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                contents = aioketraapi.models.button_change_notification.ButtonChangeNotification(
                    button_id = '0', 
                    client_id = '0', 
                    level = 56, 
                    activated = True, 
                    time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else :
            return ButtonChange(
                notification_type = 'ButtonChange',
                time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                contents = aioketraapi.models.button_change_notification.ButtonChangeNotification(
                    button_id = '0', 
                    client_id = '0', 
                    level = 56, 
                    activated = True, 
                    time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )

    def testButtonChange(self):
        """Test ButtonChange"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
