# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.lamp import Lamp  # noqa: E501
from aioketraapi.rest import ApiException

class TestLamp(unittest.TestCase):
    """Lamp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Lamp
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.lamp.Lamp()  # noqa: E501
        if include_optional :
            return Lamp(
                id = '0', 
                name = '0', 
                channel = 56, 
                parent_group_ids = [
                    '0'
                    ], 
                serial_number = '0', 
                number_of_subchannels = 56, 
                logical_address = 56
            )
        else :
            return Lamp(
        )

    def testLamp(self):
        """Test Lamp"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
