# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aioketraapi
from aioketraapi.api.scene_operations_api import SceneOperationsApi  # noqa: E501
from aioketraapi.rest import ApiException


class TestSceneOperationsApi(unittest.TestCase):
    """SceneOperationsApi unit test stubs"""

    def setUp(self):
        self.api = aioketraapi.api.scene_operations_api.SceneOperationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_root_get(self):
        """Test case for root_get

        Get keypads and groups  (and scenes in API schema 4 or later)  # noqa: E501
        """
        pass

    def test_scenes_get(self):
        """Test case for scenes_get

        Get Scenes  # noqa: E501
        """
        pass

    def test_scenes_scene_id_activate_post(self):
        """Test case for scenes_scene_id_activate_post

        Activates a scene  # noqa: E501
        """
        pass

    def test_scenes_scene_id_get(self):
        """Test case for scenes_scene_id_get

        Gets a single scene  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
