# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.inline_response2009 import InlineResponse2009  # noqa: E501
from aioketraapi.rest import ApiException

class TestInlineResponse2009(unittest.TestCase):
    """InlineResponse2009 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2009
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.inline_response2009.InlineResponse2009()  # noqa: E501
        if include_optional :
            return InlineResponse2009(
                success = True, 
                error = '0', 
                content = aioketraapi.models.keypad.Keypad(
                    id = '0', 
                    is_virtual = True, 
                    level = 56, 
                    name = '0', 
                    serial_number = '0', 
                    buttons = [
                        aioketraapi.models.button.Button(
                            active = True, 
                            id = '0', 
                            level = 56, 
                            name = '0', 
                            position = 56, 
                            is_power_button = True, 
                            scene_is_modified = True, )
                        ], )
            )
        else :
            return InlineResponse2009(
        )

    def testInlineResponse2009(self):
        """Test InlineResponse2009"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
